@@ -1,3 +1,4 @@
+# Deprecated
 from datetime import datetime
 import json
 from typing import Dict
@@ -8,6 +9,8 @@ from niota import signature
 
 
 class IotaClient():
+    """Deprecated IotaClient. Use niota.Niota or niota.IotaClient instead.
+    """
     MAINNET_NODE_URLS = [['https://chrysalis-nodes.iota.org']]
 
     def __init__(self, private_key, public_key, index_prefix=''):
@@ -51,7 +54,7 @@ class IotaClient():
         data_with_signature = json.loads(data_str)
         data = data_with_signature['data']
         base64_signature = data_with_signature['signature']
-        signature.verify_signature(self.public_key, base64_signature, data)
+        signature.verify_signature(self.public_key, base64_signature, data, raise_exception=True)
 
     def _broadcast_message(self, index: str, data: Dict) -> str:
         serialized_data = json.dumps(data, sort_keys=True)
@@ -68,8 +71,11 @@ class IotaClient():
         )
         return message_id_indexation['message_id']
 
+    def _get_current_timestamp(self):
+        return int(datetime.now().timestamp())
+
     def _create_ida_message(self, raw_cid, ida_cid, ida_mid, ida_sha256sum, metadata_cid, provider, service_message):
-        timestamp = int(datetime.now().timestamp())
+        timestamp = self._get_current_timestamp()
         ida_message = {
             'timestamp': timestamp,
             'raw_cid': raw_cid,
